.. highlight:: shell

============
Installation
============


Stable release
--------------

To install scikit-network, run this command in your terminal:

.. code-block:: console

    $ pip install scikit-network

This is the preferred method to install scikit-network, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for scikit-network can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/sknetwork-team/scikit-network

Or download the `tarball`_.

Once you have a copy of the source, if you have an installation of `pip`_:

.. code-block:: console

    $ pip install <path to the repo/path to the tarball>

Or, after having unpacked the tarball if relevant, you can install it with:

.. code-block:: console

    $ cd <scikit-network folder>
    $ python setup.py develop





.. _Github repo: https://github.com/sknetwork-team/scikit-network
.. _tarball: https://github.com/sknetwork-team/scikit-network/tarball/master
